import javax.naming.*;
import javax.naming.directory.*;

import java.util.Hashtable;

/**
 * Demonstrates how to search using different dereference alias options.
 *
 * usage: java SearchWithAlias [always|never|finding|searching]
 */
class SearchWithAlias {
    public static void main(String[] args) {


	// Set up environment for creating initial context
	Hashtable env = new Hashtable(11);
	env.put(Context.INITIAL_CONTEXT_FACTORY, 
	    "com.sun.jndi.ldap.LdapCtxFactory");
	env.put(Context.PROVIDER_URL, "ldap://localhost:389/o=JNDITutorial");

	if (args.length > 0) {
	    // Set dereference flag as requested
	    env.put("java.naming.ldap.derefAliases", args[0]);
	}

	try {
	    // Create initial context
	    DirContext ctx = new InitialDirContext(env);

	    // Perform search
	    NamingEnumeration answer = ctx.search("ou=Staff", "(cn=J*)", null);

	    // Print the answer
	    printSearchEnumeration(answer);
	} catch (NamingException e) {
	    e.printStackTrace();
	}
    }

    public static void printSearchEnumeration(NamingEnumeration enum) {
	try {
	    while (enum.hasMore()) {
		SearchResult sr = (SearchResult)enum.next();
		System.out.println(">>>" + sr.getName());
		System.out.println(sr.getAttributes());
	    }
	} catch (NamingException e) {
	    e.printStackTrace();
	}
    }

}
